@@ -13,9 +13,11 @@ sub list {
         Message.pm
         MDA.pm
         MSP.pm
+            MSP/DE/GMX.pm
             MSP/JP/Biglobe.pm
             MSP/JP/EZweb.pm
             MSP/JP/KDDI.pm
+            MSP/RU/MailRu.pm
             MSP/US/AmazonSES.pm
             MSP/US/Aol.pm
             MSP/US/Facebook.pm
